@@ -65,15 +65,10 @@ filter_trim <- function(eventlog,
 	colnames(f_eventlog)[colnames(f_eventlog) == "activity_instance_classifier"] <- activity_instance_id(eventlog)
 
 
-	eventlog <- eventlog(eventlog = f_eventlog,
-						 activity_id = activity_id(eventlog),
-						 case_id = case_id(eventlog),
-						 activity_instance_id = activity_instance_id(eventlog),
-						 lifecycle_id = lifecycle_id(eventlog),
-						 timestamp = timestamp(eventlog),
-						 resource_id = resource_id(eventlog))
+	output <- re_map(f_eventlog, mapping(eventlog))
 
-	return(eventlog)
+
+	return(output)
 }
 
 #' @rdname filter_trim
