@@ -4,7 +4,9 @@ idle_time_case <- function(eventlog, units) {
 	colnames(eventlog)[colnames(eventlog) == timestamp(eventlog)] <- "timestamp_classifier"
 
 
-	eventlog %>%
+	e <- as.data.frame(eventlog)
+
+	e %>%
 		mutate(activate = ifelse(lifecycle_identifier == "start", 1, ifelse(lifecycle_identifier == "complete", -1, 0))) %>%
 		group_by_(case_id(eventlog)) %>%
 		arrange_("timestamp_classifier") %>%
