@@ -9,7 +9,9 @@ resource_specialisation_log <- function(eventlog) {
 	eventlog %>%
 		group_by_(resource_classifier, event_classifier) %>%
 		summarize() %>%
-		summarize(freq = n()) %>%
+		summarize(freq = n()) -> raw
+
+	raw %>%
 		summarize(nr_of_activity_types = n_activities(eventlog),
 				  min = min(freq),
 				  q1 = quantile(freq, 0.25),
@@ -18,6 +20,10 @@ resource_specialisation_log <- function(eventlog) {
 				  q3 = quantile(freq, 0.75),
 				  max = max(freq),
 				  st_dev = sd(freq)) %>%
-		mutate(iqr = q3 - q1) %>%
-		return()
+		mutate(iqr = q3 - q1) -> output
+
+	attr(output, "raw") <- raw
+
+	return(output)
+
 }
